@@ -1,8 +1,7 @@
 __ver_major__ = 1
-__ver_minor__ = 1
-__ver_patch__ = 3
-__ver_tuple__ = (__ver_major__, __ver_minor__, __ver_patch__)
-__version__ = "%d.%d.%d" % __ver_tuple__
+__ver_minor__ = 2
+__ver_patch__ = 1
+__version__ = f"{__ver_major__}.{__ver_minor__}.{__ver_patch__}"
 
 __all__ = ['query', 'io', 'corpus', 'config', 'exceptions', 'CorpusContext', 'CorpusConfig']
 
