@@ -8,8 +8,10 @@ from decimal import Decimal
 from influxdb import InfluxDBClient
 from influxdb.exceptions import InfluxDBClientError
 
-from ..acoustics import analyze_pitch, analyze_formant_tracks, analyze_intensity, \
+from ..acoustics import analyze_pitch, analyze_formant_tracks, analyze_formant_points, analyze_intensity, \
     analyze_script, analyze_track_script, analyze_utterance_pitch, update_utterance_pitch_track, analyze_vot
+
+from ..acoustics.formants.helper import save_formant_point_data
 from ..acoustics.classes import Track, TimePoint
 from .syllabic import SyllabicContext
 from ..acoustics.utils import load_waveform, generate_spectrogram
@@ -148,7 +150,7 @@ def to_seconds(time_string):
             d = datetime.strptime(time_string, '%Y-%m-%dT%H:%M:%SZ')
             s = 60 * 60 * d.hour + 60 * d.minute + d.second + d.microsecond / 1e6
         except:
-            m = re.search('T(\d{2}):(\d{2}):(\d+)\.(\d+)?', time_string)
+            m = re.search(r'T(\d{2}):(\d{2}):(\d+)\.(\d+)?', time_string)
             p = m.groups()
 
             s = 60 * 60 * int(p[0]) + 60 * int(p[1]) + int(p[2]) + int(p[3][:6]) / 1e6
@@ -256,7 +258,9 @@ class AudioContext(SyllabicContext):
         signal, sr = self.load_waveform(discourse, file_type, begin, end)
         return generate_spectrogram(signal, sr)
 
-    def analyze_pitch(self, source='praat', algorithm='base', stop_check=None, call_back=None, multiprocessing=True):
+    def analyze_pitch(self, source='praat', algorithm='base',
+                      absolute_min_pitch=50, absolute_max_pitch=500, adjusted_octaves=1,
+                      stop_check=None, call_back=None, multiprocessing=True):
         """
         Analyze pitch tracks and save them to the database.
 
@@ -268,6 +272,12 @@ class AudioContext(SyllabicContext):
             Program to use for analyzing pitch, either ``praat`` or ``reaper``
         algorithm : str
             Algorithm to use, ``base``, ``gendered``, or ``speaker_adjusted``
+        absolute_min_pitch : int
+            Absolute pitch floor
+        absolute_max_pitch : int
+            Absolute pitch ceiling
+        adjusted_octaves : int
+            How many octaves around the speaker's mean pitch to set the speaker adjusted pitch floor and ceiling
         stop_check : callable
             Function to check whether processing should stop early
         call_back : callable
@@ -275,7 +285,8 @@ class AudioContext(SyllabicContext):
         multiprocessing : bool
             Flag whether to use multiprocessing or threading
         """
-        analyze_pitch(self, source, algorithm, stop_check, call_back, multiprocessing=multiprocessing)
+        analyze_pitch(self, source, algorithm, stop_check=stop_check, call_back=call_back, multiprocessing=multiprocessing,
+                      absolute_min_pitch=absolute_min_pitch, absolute_max_pitch=absolute_max_pitch, adjusted_octaves=adjusted_octaves)
 
     def analyze_utterance_pitch(self, utterance, source='praat', **kwargs):
         """
@@ -363,6 +374,28 @@ class AudioContext(SyllabicContext):
                     vot_min=vot_min, vot_max=vot_max, window_min=window_min,
                     window_max=window_max)
 
+    def analyze_formant_points(self, stop_check=None, call_back=None, multiprocessing=True,
+                               vowel_label=None):
+        """
+        Compute formant tracks and save them to the database
+
+        See :meth:`polyglotdb.acoustics.formants.base.analyze_formant_points` for more details.
+
+        Parameters
+        ----------
+        stop_check : callable
+            Function to check whether to terminate early
+        call_back : callable
+            Function to report progress
+        multiprocessing : bool
+            Flag to use multiprocessing, defaults to True, if False uses threading
+        vowel_label : str, optional
+            Optional subset of phones to compute tracks over.  If None, then tracks over utterances are computed.
+        """
+        data = analyze_formant_points(self,  stop_check=stop_check, call_back=call_back,
+                               multiprocessing=multiprocessing, vowel_label=vowel_label)
+        save_formant_point_data(self, data)
+
     def analyze_formant_tracks(self, source='praat', stop_check=None, call_back=None, multiprocessing=True,
                                vowel_label=None):
         """
@@ -579,9 +612,9 @@ class AudioContext(SyllabicContext):
         dict
             Information for the audio file path
         """
-        statement = '''MATCH (d:Discourse:{corpus_name}) WHERE d.name = {{discourse_name}} return d'''.format(
+        statement = '''MATCH (d:Discourse:{corpus_name}) WHERE d.name = $discourse_name return d'''.format(
             corpus_name=self.cypher_safe_name)
-        results = self.execute_cypher(statement, discourse_name=discourse).records()
+        results = self.execute_cypher(statement, discourse_name=discourse)
         for r in results:
             d = r['d']
             break
@@ -786,9 +819,9 @@ class AudioContext(SyllabicContext):
             file_path, begin, end, channel, utterance_id = seg.file_path, seg.begin, seg.end, seg.channel, seg[
                 'utterance_id']
             res = self.execute_cypher(
-                'MATCH (d:Discourse:{corpus_name}) where d.low_freq_file_path = {{file_path}} OR '
-                'd.vowel_file_path = {{file_path}} OR '
-                'd.consonant_file_path = {{file_path}} '
+                'MATCH (d:Discourse:{corpus_name}) where d.low_freq_file_path = $file_path OR '
+                'd.vowel_file_path = $file_path OR '
+                'd.consonant_file_path = $file_path '
                 'RETURN d.name as name'.format(
                     corpus_name=self.cypher_safe_name), file_path=file_path)
             for r in res:
@@ -813,6 +846,8 @@ class AudioContext(SyllabicContext):
                     v = sanitize_value(value[name], type)
                     if v is not None:
                         fields[name] = v
+                    elif type in [int, float]:
+                        fields[name] = type(-1)
                 if not fields:
                     continue
                 if set_label is None:
@@ -1008,7 +1043,7 @@ class AudioContext(SyllabicContext):
             set_statements = []
             for measure in measures.keys():
                 set_statements.append(statistic_template.format(statistic=statistic, measure=measure))
-            statement = '''WITH {{data}} as data
+            statement = '''WITH $data as data
                         UNWIND data as d
                         MATCH (s:Speaker:{corpus_name}), (p:phone_type:{corpus_name})
                         WHERE p.label = d.phone AND s.name = d.speaker
@@ -1033,7 +1068,7 @@ class AudioContext(SyllabicContext):
             set_statements = []
             for measure in measures.keys():
                 set_statements.append(statistic_template.format(statistic=statistic, measure=measure))
-            statement = '''WITH {{data}} as data
+            statement = '''WITH $data as data
                                 UNWIND data as d
                                 MATCH (n:phone_type:{corpus_name})
                                 WHERE n.label = d.phone
@@ -1055,7 +1090,7 @@ class AudioContext(SyllabicContext):
             set_statements = []
             for measure in measures.keys():
                 set_statements.append(statistic_template.format(statistic=statistic, measure=measure))
-            statement = '''WITH {{data}} as data
+            statement = '''WITH $data as data
                             UNWIND data as d
                             MATCH (n:Speaker:{corpus_name})
                             WHERE n.name = d.speaker
@@ -1106,17 +1141,17 @@ class AudioContext(SyllabicContext):
         if by_phone and by_speaker:
             statement = '''MATCH (p:phone_type:{corpus_name})-[n:spoken_by]->(s:Speaker:{corpus_name}) 
             return {return_list} LIMIT 1'''.format(corpus_name=self.cypher_safe_name, return_list=', '.join(returns))
-            results = self.execute_cypher(statement).records()
+            results = self.execute_cypher(statement)
             try:
-                first = next(results)
-            except StopIteration:
+                first = results[0]
+            except IndexError:
                 first = None
             if first is None:
                 self.encode_acoustic_statistic(acoustic_name, statistic, by_phone, by_speaker)
             statement = '''MATCH (p:phone_type:{corpus_name})-[n:spoken_by]->(s:Speaker:{corpus_name})
             return p.label as phone, s.name as speaker, {return_list}'''.format(
                 corpus_name=self.cypher_safe_name, return_list=', '.join(returns))
-            results = self.execute_cypher(statement).records()
+            results = self.execute_cypher(statement)
             results = {(x['speaker'], x['phone']): [x[n] for n in measures] for x in results}
 
         elif by_phone:
@@ -1125,7 +1160,7 @@ class AudioContext(SyllabicContext):
             statement = '''MATCH (n:phone_type:{corpus_name})
             return n.label as phone, {return_list}'''.format(
                 corpus_name=self.cypher_safe_name, return_list=', '.join(returns))
-            results = self.execute_cypher(statement).records()
+            results = self.execute_cypher(statement)
             results = {x['phone']: [x[n] for n in measures] for x in results}
         elif by_speaker:
             if not self.hierarchy.has_speaker_property(measures[0]):
@@ -1133,7 +1168,7 @@ class AudioContext(SyllabicContext):
             statement = '''MATCH (n:Speaker:{corpus_name})
             return n.name as speaker, {return_list}'''.format(
                 corpus_name=self.cypher_safe_name, return_list=', '.join(returns))
-            results = self.execute_cypher(statement).records()
+            results = self.execute_cypher(statement)
             results = {x['speaker']: [x[n] for n in measures] for x in results}
         return results
 
