@@ -1,8 +1,8 @@
 from collections import Counter
-from textgrid import TextGrid, IntervalTier
 from .aligner import AlignerParser
 
 from polyglotdb.io.parsers.speaker import DirectorySpeakerParser
+from praatio import textgrid
 
 
 class LabbCatParser(AlignerParser):
@@ -48,9 +48,8 @@ class LabbCatParser(AlignerParser):
         :class:`~textgrid.TextGrid`
             TextGrid object
         """
-        tg = TextGrid(strict=False)
         try:
-            tg.read(path)
+            tg = textgrid.openTextgrid(path, includeEmptyIntervals=True)
             new_tiers = []
             dup_tiers_maxes = {k:0 for k,v in Counter([t.name for t in tg.tiers]).items() if v > 1}
             dup_tiers_inds = {k:0 for k in dup_tiers_maxes.keys()}
