@@ -9,8 +9,6 @@ from ..base.elements import (ClauseElement, EqualClauseElement as BaseEqualClaus
                              NullClauseElement as BaseNullClauseElement,
                              NotNullClauseElement as BaseNotNullClauseElement, )
 
-from ...exceptions import NodeAttributeError
-
 
 class AnnotationClauseElement(ClauseElement):
     """
@@ -44,7 +42,7 @@ class PrecedenceClauseElement(AnnotationClauseElement):
         """
         Create a Cypher parameter for the value of the clause.
         """
-        return '{`%s%s`}' % (self.value_alias_prefix.replace('`', ''), self.node.alias.replace('`', ''))
+        return '$`%s%s`' % (self.value_alias_prefix.replace('`', ''), self.node.alias.replace('`', ''))
 
     def for_cypher(self):
 
