@@ -1,5 +1,4 @@
 
-
 from polyglotdb.exceptions import GraphQueryError
 
 from ..base.results import BaseQueryResults, BaseRecord
@@ -16,6 +15,7 @@ from .models import LinguisticAnnotation, SubAnnotation, Speaker, Discourse
 def hydrate_model(r, to_find, to_find_type, to_preload, to_preload_acoustics, corpus):
     base_annotation_type = to_find.replace('node_', '')
     a = LinguisticAnnotation(corpus)
+    r[to_find]['neo4j_label'] = to_find.replace('node_', '')
     a.node = r[to_find]
     a.type_node = r[to_find_type]
     a._preloaded = True
@@ -32,6 +32,7 @@ def hydrate_model(r, to_find, to_find_type, to_preload, to_preload_acoustics, co
     for pre in to_preload:
         if isinstance(pre, HierarchicalAnnotation):
             pa = LinguisticAnnotation(corpus)
+            r[pre.alias]['neo4j_label'] = pre.alias.split('_')[-1]
             pa.node = r[pre.alias]
             pa.type_node = r[pre.type_alias]
             pa._preloaded = True
@@ -42,6 +43,7 @@ def hydrate_model(r, to_find, to_find_type, to_preload, to_preload_acoustics, co
             subannotations = r[pre.collection_alias]
             for s in subannotations:
                 sa = SubAnnotation(corpus)
+                s['neo4j_label'] = pre.collection_alias.split('_in_')[0].replace('node_', '')
                 sa._annotation = a
                 sa.node = s
                 if sa._type not in a._subannotations:
@@ -54,12 +56,14 @@ def hydrate_model(r, to_find, to_find_type, to_preload, to_preload_acoustics, co
             subannotations = r[pre.subannotation_alias]
             for i, e in enumerate(subs):
                 pa = LinguisticAnnotation(corpus)
+                e['neo4j_label'] = pre.collected_node.alias.replace('node_', '')
                 pa.node = e
                 pa.type_node = sub_types[i]
                 pa._preloaded = True
                 for s in subannotations[i]:
                     sa = SubAnnotation(corpus)
                     sa._annotation = pa
+                    s['neo4j_label'] = pre.subannotation_alias.split('_in_')[0].replace('node_', '')
                     sa.node = s
                     if sa._type not in pa._subannotations:
                         pa._subannotations[sa._type] = []
@@ -77,6 +81,7 @@ def hydrate_model(r, to_find, to_find_type, to_preload, to_preload_acoustics, co
         pa = LinguisticAnnotation(corpus)
         pa._preloaded = True
         pa = LinguisticAnnotation(corpus)
+        r[pre.alias]['neo4j_label'] = pre.alias.split('_')[-1]
         pa.node = r[pre.alias]
         pa.type_node = r[pre.type_alias]
         pa._discourse = a._discourse
@@ -92,6 +97,7 @@ def hydrate_model(r, to_find, to_find_type, to_preload, to_preload_acoustics, co
             break
         pa = LinguisticAnnotation(corpus)
         pa._preloaded = True
+        r[pre.alias]['neo4j_label'] = pre.alias.split('_')[-1]
         pa.node = r[pre.alias]
         pa.type_node = r[pre.type_alias]
         pa._discourse = a._discourse
@@ -110,6 +116,7 @@ def hydrate_model(r, to_find, to_find_type, to_preload, to_preload_acoustics, co
             pa = LinguisticAnnotation(corpus)
             pa._preloaded = True
             pa = LinguisticAnnotation(corpus)
+            r[pre.alias]['neo4j_label'] = pre.alias.split('_')[-1]
             pa.node = r[pre.alias]
             pa.type_node = r[pre.type_alias]
             pa._discourse = a._discourse
@@ -125,6 +132,7 @@ def hydrate_model(r, to_find, to_find_type, to_preload, to_preload_acoustics, co
                 break
             pa = LinguisticAnnotation(corpus)
             pa._preloaded = True
+            r[pre.alias]['neo4j_label'] = pre.alias.split('_')[-1]
             pa.node = r[pre.alias]
             pa.type_node = r[pre.type_alias]
             pa._discourse = a._discourse
@@ -215,7 +223,7 @@ class QueryResults(BaseQueryResults):
                 for point in line.track:
                     line = {}
                     line.update(baseline)
-                    line.update({'time': point.time})
+                    line.update({'time': round(point.time, 4)})
                     line.update(point.select_values(self.track_columns))
                     yield line
             else:
@@ -229,8 +237,8 @@ class QueryResults(BaseQueryResults):
 
 class AnnotationRecord(BaseRecord):
     def __init__(self, result):
-        self.columns = result.keys()
-        self.values = result.values()
+        self.columns = list(result.keys())
+        self.values = list(result.values())
         self.acoustic_columns = []
         self.acoustic_values = []
         self.track = Track()
